==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicTableUI__24KeyHandler.h <==
// class javax.swing.plaf.basic.BasicTableUI$KeyHandler

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class ce39015e83dac73d javax_swing_plaf_basic_BasicTableUI__24KeyHandler

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicTableUI__24KeyHandler_H_
#define _JC_javax_swing_plaf_basic_BasicTableUI__24KeyHandler_H_

// Forward structure declarations
struct _jc_java_awt_event_KeyEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicTableUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$sub_refs	_jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$refs	_jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$nonrefs	_jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$object	_jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$vmethods	_jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$vtable	_jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$vtype	_jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$method$_init$f8f5aa98e66ac669(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$object *, struct _jc_javax_swing_plaf_basic_BasicTableUI$object *);

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$method$keyPressed$d7fe1c88a82640ee(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$object *, struct _jc_java_awt_event_KeyEvent$object *);
extern void _jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$method$keyReleased$c1315bcf69bed992(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$object *, struct _jc_java_awt_event_KeyEvent$object *);
extern void _jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$method$keyTyped$f9f3a1945675f073(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$object *, struct _jc_java_awt_event_KeyEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$method_info$keyPressed$d7fe1c88a82640ee;
extern _jc_method _jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$method_info$keyReleased$c1315bcf69bed992;
extern _jc_method _jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$method_info$keyTyped$f9f3a1945675f073;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$vmethods {
	void	(*keyPressed$d7fe1c88a82640ee)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$object *, struct _jc_java_awt_event_KeyEvent$object *);
	void	(*keyReleased$c1315bcf69bed992)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$object *, struct _jc_java_awt_event_KeyEvent$object *);
	void	(*keyTyped$f9f3a1945675f073)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$object *, struct _jc_java_awt_event_KeyEvent$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$vmethods	javax_swing_plaf_basic_BasicTableUI__24KeyHandler;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicTableUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$refs {
    _jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$sub_refs	javax_swing_plaf_basic_BasicTableUI__24KeyHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$sub_nonrefs	javax_swing_plaf_basic_BasicTableUI__24KeyHandler;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$object {
	_jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$vtype _jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicTableUI__24KeyHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicTableUI__24KeyHandler_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicTableUI__24KeyHandler.h <==
// class javax.swing.plaf.basic.BasicTableUI$KeyHandler

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class ce39015e83dac73d javax_swing_plaf_basic_BasicTableUI__24KeyHandler

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicTableUI__24KeyHandler_H_
#define _JC_javax_swing_plaf_basic_BasicTableUI__24KeyHandler_H_

// Forward structure declarations
struct _jc_java_awt_event_KeyEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicTableUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$sub_refs	_jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$refs	_jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$nonrefs	_jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$object	_jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$vmethods	_jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$vtable	_jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$vtype	_jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$method$_init$f8f5aa98e66ac669(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$object *, struct _jc_javax_swing_plaf_basic_BasicTableUI$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$method$keyPressed$d7fe1c88a82640ee(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$object *, struct _jc_java_awt_event_KeyEvent$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$method$keyReleased$c1315bcf69bed992(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$object *, struct _jc_java_awt_event_KeyEvent$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$method$keyTyped$f9f3a1945675f073(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$object *, struct _jc_java_awt_event_KeyEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$method_info$keyPressed$d7fe1c88a82640ee;
extern _jc_method _jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$method_info$keyReleased$c1315bcf69bed992;
extern _jc_method _jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$method_info$keyTyped$f9f3a1945675f073;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$vmethods {
	void	(*keyPressed$d7fe1c88a82640ee)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$object *, struct _jc_java_awt_event_KeyEvent$object *) _JC_JCNI_ATTR;
	void	(*keyReleased$c1315bcf69bed992)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$object *, struct _jc_java_awt_event_KeyEvent$object *) _JC_JCNI_ATTR;
	void	(*keyTyped$f9f3a1945675f073)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$object *, struct _jc_java_awt_event_KeyEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$vmethods	javax_swing_plaf_basic_BasicTableUI__24KeyHandler;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicTableUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$refs {
    _jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$sub_refs	javax_swing_plaf_basic_BasicTableUI__24KeyHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$sub_nonrefs	javax_swing_plaf_basic_BasicTableUI__24KeyHandler;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$object {
	_jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$vtype _jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicTableUI__24KeyHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicTableUI__24KeyHandler$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicTableUI__24KeyHandler_H_ */
